=======
History
=======

0.2.0
-----

- Add support for Django 2.1
- Add support for Python 3.7
- Migrate to `complement` from `exists` and `neexists`

0.1.0
-----

- Migrate installation to backend settings
- Support `exists` and `neexists` lookups

0.0.1 - 0.0.2
-------------

- Support extra regex lookups
- Support negaete lookups
